from subprocess import Popen
import sys

from ._env import (
    JS,
    SRC,
    join,
    node_bin,
    external,
    extension,
    transform,
    IS_WIN,
)


def main(**opts):
    args = [
        node_bin("browserify"),
        "--standalone", "nbpresent-deps",
    ] + extension + external(
        "jquery", "base/js/namespace", "notebook/js/celltoolbar"
    ) + transform + [
        "--outfile", join(JS, "nbpresent.deps.min.js"),
        join(SRC, "es6", "vendor.es6")
    ] + opts.get("browserify", [])
    return Popen(args, shell=IS_WIN).wait()


if __name__ == "__main__":
    sys.exit(main())



import os

from notebook import DEFAULT_STATIC_FILES_PATH

APP_ROOT = os.path.abspath(os.path.join(os.path.dirname(__file__), ".."))
ASSETS = os.path.join(APP_ROOT, "static", "nbpresent")
NB_ASSETS = [os.path.join(DEFAULT_STATIC_FILES_PATH, *bits) for bits in [
    ["components", "requirejs", "require.js"]
]]
STANDALONE_ASSETS = [
    os.path.join(ASSETS, "js", "nbpresent.static.min.js"),
    os.path.join(ASSETS, "css", "nbpresent.min.css"),
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup


# should be loaded below
__version__ = None

with open('nbpresent/_version.py') as version:
    exec(version.read())

with open('./README.rst') as readme:
    README = readme.read()

setup(
    name="nbpresent",
    version=__version__,
    description="Next generation slides from Jupyter Notebooks",
    long_description=README,
    author="Nicholas Bollweg",
    author_email="nbollweg@continuum.io",
    license="BSD-3-Clause",
    url="https://github.com/Anaconda-Platform/nbpresent",
    keywords="ipython jupyter markdown presentation slides revealjs d3",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Framework :: IPython",
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License"
    ],
    packages=["nbpresent"],
    setup_requires=["notebook"],
    tests_require=["nose", "requests", "coverage"],
    include_package_data=True,
    entry_points={
        'console_scripts': ['nbpresent=nbpresent.export:main'],
    }
)



from .html import PresentExporter

from nbbrowserpdf.exporters.pdf import BrowserPDFExporter


class PDFPresentExporter(PresentExporter, BrowserPDFExporter):
    def pdf_capture_args(self):
        return [
            "--capture-server-class",
            "nbpresent.exporters.pdf_capture:SlideCaptureServer"
        ]



import codecs
import os
import json

from collections import (
    OrderedDict,
    defaultdict
)

from nbconvert.exporters.html import HTMLExporter

from .base import (
    APP_ROOT,
    STANDALONE_ASSETS,
    NB_ASSETS
)


class PresentExporter(HTMLExporter):
    def __init__(self, *args, **kwargs):
        # TODO: this probably isn't the right way
        kwargs.update(
            template_file="nbpresent",
            template_path=[os.path.join(APP_ROOT, "templates")]
        )
        super(PresentExporter, self).__init__(*args, **kwargs)

    def from_notebook_node(self, nb, resources=None, **kw):
        bin_ext = ["woff", "ttf"]

        resources = self._init_resources(resources)

        assets = defaultdict(OrderedDict)

        to_inline = NB_ASSETS + STANDALONE_ASSETS

        for filename in to_inline:
            ext = filename.split(".")[-1]
            mode = "rb" if ext in bin_ext else "r"
            with codecs.open(filename, mode, encoding="utf-8") as fp:
                assets[ext].update({
                    os.path.basename(filename): fp.read()
                })

        resources.update(
            nbpresent={
                "metadata": json.dumps(nb.metadata.get("nbpresent", {}),
                                       indent=2,
                                       sort_keys=True)
            },
            nbpresent_assets=assets
        )

        return super(PresentExporter, self).from_notebook_node(
            nb,
            resources=resources,
            **kw
        )



from subprocess import Popen
import sys

from ._env import (
    SRC,
    join,
    node_bin,
    IS_WIN,
)


def main(**opts):
    args = [
        node_bin("r.js{}".format(".cmd" if IS_WIN else "")),
        "-o", join(SRC, "js", "build.js"),
    ] + opts.get("requirejs", [])
    return Popen(args, shell=IS_WIN).wait()


if __name__ == "__main__":
    sys.exit(main())



from glob import glob
import os
import socket
import subprocess
import tempfile
import sys
import platform

from ..export import export


IS_WIN = "Windows" in platform.system()


# utility function
def join(*bits):
    return os.path.abspath(os.path.join(*bits))


here = os.path.dirname(__file__)

http_module = None


def node_bin(*bits):
    return os.path.abspath(
        os.path.join(here, "..", "..", "node_modules", ".bin", *bits))

try:
    import http.server as httpd
    http_module = "http.server"
except ImportError:
    import SimpleHTTPServer as httpd
    http_module = "SimpleHTTPServer"

print("nbpresent export test using", httpd)


def unused_port():
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.bind(('localhost', 0))
    addr, port = sock.getsockname()
    sock.close()
    return port


def test_export():
    tmpdir = tempfile.mkdtemp()
    env = dict(os.environ)
    env.update(
        NBPRESENT_TEST_HTTP_PORT=str(unused_port()),
        PATH=os.pathsep.join([env["PATH"], node_bin()])
    )

    httpd = subprocess.Popen([
            sys.executable, "-m", http_module,
            env["NBPRESENT_TEST_HTTP_PORT"],
            "--bind=127.0.0.1"
        ],
        cwd=tmpdir)

    try:
        export(
            join(here, "notebooks", "Basics.ipynb"),
            join(tmpdir, "Basics.html"),
            "html")
        args = [
            "casperjs{}".format(".cmd" if IS_WIN else ""),
            "test",
            "--fail-fast",
            "--includes={}".format(
                ",".join(glob(join(here, 'js', '_*.js')))),
        ] + glob(join(here, 'js', 'test_export_*.js'))

        proc = subprocess.Popen(
            args,
            stderr=subprocess.PIPE,
            env=env
        )
        proc.communicate()

        assert proc.returncode == 0
    finally:
        httpd.kill()


if __name__ == '__main__':
    test_export()



from nbbrowserpdf.exporters.pdf_capture import CaptureServer

VIEWPORT = (1920, 1080)


class SlideCaptureServer(CaptureServer):
    """ CaptureServer to generate multi-page PDF based on nbpresent metadata
    """
    ghost_cmd = "nbpresent.exporters.pdf_ghost"
